from .canvas_robot import CanvasRobot, LocalDAL, ENROLLMENT_TYPES, STUDADMIN, \
    EDUCATIONS, COMMUNITIES, SHORTNAMES, AC_YEAR
